@@ -1,9 +1,16 @@
-#' Adverse Events Dataset
+#' Adverse Events Dataset-updated
+#'
+#' An updated SDTM AE dataset that uses the CDISC pilot project
+#'
+#' @source \url{https://github.com/pharmaverse/admiral.test/blob/main/data/admiral_ae.rda}
+"admiral_ae"
+
+#' Adverse Events Dataset-raw
 #'
 #' A SDTM AE dataset from the CDISC pilot project
 #'
 #' @source \url{https://github.com/cdisc-org/sdtm-adam-pilot-project/blob/master/updated-pilot-submission-package/900172/m5/datasets/cdiscpilot01/tabulations/sdtm/ae.xpt?raw=true} # nolint
-"admiral_ae"
+"raw_ae"
 
 #' Concomitant Medication Dataset
 #'
@@ -77,6 +84,13 @@
 #' @source \url{https://github.com/cdisc-org/sdtm-adam-pilot-project/blob/master/updated-pilot-submission-package/900172/m5/datasets/cdiscpilot01/tabulations/sdtm/mh.xpt?raw=true} # nolint
 "raw_mh"
 
+#' Ophthalmic Examinations Dataset
+#'
+#' A SDTM OE dataset simulated by Ophthalmology team
+#'
+#' @author Gordon Miller
+"admiral_oe"
+
 #' Pharmacokinetics Concentrations Dataset
 #'
 #' A SDTM PC dataset simulated by Antonio Rodríguez Contestí
@@ -98,8 +112,22 @@
 #' A SDTM QS dataset from the CDISC pilot project
 #'
 #' @source \url{https://github.com/cdisc-org/sdtm-adam-pilot-project/blob/master/updated-pilot-submission-package/900172/m5/datasets/cdiscpilot01/tabulations/sdtm/qs.xpt?raw=true} # nolint
+"raw_qs"
+
+#' Questionnaire Dataset
+#'
+#' A SDTM QS dataset from the CDISC pilot project & Ophthalmology test data
+#'
+#' @source \url{https://github.com/pharmaverse/admiral.test/blob/main/data/admiral_qs.rda} # nolint
 "admiral_qs"
 
+#' Subject Characteristic Dataset
+#'
+#' A SDTM SC dataset simulated by Ophthalmology team
+#'
+#' @author Gordon Miller
+"admiral_sc"
+
 #' Tumor Identification Dataset
 #'
 #' A SDTM TU dataset simulated by Gopi Vegesna
